@@ -38,8 +38,8 @@ class FormBrowser extends CMSModule
 	{
 		global $gCms;
 		$this->CMSModule();
-        $this->module_ptr = &$this;
-        $this->dbHandle = $gCms->GetDb();
+    $this->module_ptr = &$this;
+    $this->dbHandle = $gCms->GetDb();
 		require_once dirname(__FILE__).'/classes/Browser.class.php';
 	}
 
@@ -65,7 +65,7 @@ class FormBrowser extends CMSModule
 
 	function GetVersion()
 	{
-		return '0.3.2';
+		return '0.4';
 	}
 
 	function GetHelp($lang = 'en_US')
@@ -110,7 +110,7 @@ class FormBrowser extends CMSModule
 
 	function VisibleToAdminUser()
 	{
-        return true;
+        return $this->CheckPermission('Modify Browsers');
 	}
 	
     function AdminStyle()
@@ -187,6 +187,12 @@ class FormBrowser extends CMSModule
 		$this->CreateParameter('sort_dir','null',$this->Lang('formbrowser_params_sort_dir'));
 		$this->SetParameterType('sort_dir',CLEAN_STRING);
 
+		$this->CreateParameter('filter_field','null',$this->Lang('formbrowser_params_filter_field'));
+		$this->SetParameterType('filter_field',CLEAN_STRING);
+
+		$this->CreateParameter('filter_value','null',$this->Lang('formbrowser_params_filter_value'));
+		$this->SetParameterType('filter_value',CLEAN_STRING);
+
    	}
 
     function SearchResult($returnid, $articleid, $attr = '')
