@@ -28,5 +28,5 @@ if (! $this->CheckAccess()) exit;
 			}
 		$aebrowser->BrowserShowList($id, $returnid, $this, $params,'admin_list_fields',true);
 
-		echo $this->ProcessTemplate('admin_browse_list.tpl');
+		echo $this->ProcessTemplateFromDatabase('fbr_alist_'.$aebrowser->GetId());
 ?>
