@@ -11,7 +11,9 @@ if (! $this->CheckAccess()) exit;
 
 		$this->buildBrowseNav($id,$params,$returnid,false);
 		$aebrowser = new fbrBrowser($this, $params, true);
-		$this->smarty->assign('in_admin','true');
+		$params['in_formbrowser'] = 1;
+		$params['in_admin'] = 1;
+		$this->smarty->assign('in_admin',$params['in_admin']);
 		$this->smarty->assign('fbr_id',$params['response_id']);
 		$fb = $this->GetModuleInstance('FormBuilder');
 
