@@ -431,7 +431,7 @@ class fbrBrowser {
 			// we have a list of fields and their names, now we need to manipulate that according to our uses.
 			for ($i=0;$i<count($vals);$i++)
 				{
-				if (! empty($vals[$i]->admin_approved) && $vals[$i]->admin_approved > 0)
+				if (! empty($vals[$i]->admin_approved))
 					{
 					$vals[$i]->admin_approval = $mod_ptr->CreateLink($id,
 						'admin_approve_resp', '',
@@ -916,8 +916,10 @@ array_merge($_searchfield, array('fbrp_page'=>($this->Page + 1),'form_id'=>$this
 			{
 			$this->LoadBrowser(true);
 			}
-        $this->module_ptr->DeleteTemplate('fbr_full_'.$this->Id);
-        $this->module_ptr->DeleteTemplate('fbr_list_'.$this->Id);
+        $this->module_ptr->DeleteTemplate('fbr_ulist_'.$this->Id);
+        $this->module_ptr->DeleteTemplate('fbr_ufull_'.$this->Id);
+        $this->module_ptr->DeleteTemplate('fbr_alist_'.$this->Id);
+        $this->module_ptr->DeleteTemplate('fbr_afull_'.$this->Id);
 		$sql = 'DELETE FROM ' . cms_db_prefix() . 'module_fbr_browser where browser_id=?';
 		$res = $this->module_ptr->dbHandle->Execute($sql, array($this->Id));
 		$sql = 'DELETE FROM ' . cms_db_prefix() . 'module_fbr_browser_attr where browser_id=?';
@@ -1024,7 +1026,7 @@ array_merge($_searchfield, array('fbrp_page'=>($this->Page + 1),'form_id'=>$this
 
 		if($this->Id > 0)
     	{
-    		$mod->smarty->assign('submit_button',$mod->CreateInputHidden($id, 'active_tab', '', 'id="fbr_atab"').
+    		$mod->smarty->assign('submit_button',$mod->CreateInputHidden($id, 'active_tab', '').
     			$mod->CreateInputSubmit($id, 'fbrp_submit',
     			$mod->Lang('save_and_continue'),'onclick="jQuery(this).fbr_set_tab()"'));
     		$mod->smarty->assign('hidden',
